pub struct DictlayerdataDictWords {
pub derivatives: Option<Vec<DictlayerdataDictWordsDerivatives>>,
pub examples: Option<Vec<DictlayerdataDictWordsExamples>>,
pub senses: Option<Vec<DictlayerdataDictWordsSenses>>,
pub source: Option<DictlayerdataDictWordsSource>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
derivatives: Option<Vec<DictlayerdataDictWordsDerivatives>>no description provided
examples: Option<Vec<DictlayerdataDictWordsExamples>>no description provided
senses: Option<Vec<DictlayerdataDictWordsSenses>>no description provided
source: Option<DictlayerdataDictWordsSource>The words with different meanings but not related words, e.g. “go” (game) and “go” (verb).