pub struct DictlayerdataDictWordsSource {
pub attribution: Option<String>,
pub url: Option<String>,
}Expand description
The words with different meanings but not related words, e.g. “go” (game) and “go” (verb).
This type is not used in any activity, and only used as part of another schema.
Fields
attribution: Option<String>no description provided
url: Option<String>no description provided