pub struct Discoveryclusters {
pub clusters: Option<Vec<DiscoveryclustersClusters>>,
pub kind: Option<String>,
pub total_clusters: Option<i32>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get personalizedstream (response)
Fields
clusters: Option<Vec<DiscoveryclustersClusters>>no description provided
kind: Option<String>Resorce type.
total_clusters: Option<i32>no description provided