pub struct Layersummaries {
pub items: Option<Vec<Layersummary>>,
pub kind: Option<String>,
pub total_items: Option<i32>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list layers (response)
Fields
items: Option<Vec<Layersummary>>A list of layer summary items.
kind: Option<String>Resource type.
total_items: Option<i32>The total number of layer summaries found.