pub struct Review {
pub author: Option<ReviewAuthor>,
pub content: Option<String>,
pub date: Option<String>,
pub full_text_url: Option<String>,
pub kind: Option<String>,
pub rating: Option<String>,
pub source: Option<ReviewSource>,
pub title: Option<String>,
pub type_: Option<String>,
pub volume_id: Option<String>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
Author of this review.
content: Option<String>Review text.
date: Option<String>Date of this review.
full_text_url: Option<String>URL for the full review text, for reviews gathered from the web.
kind: Option<String>Resource type for a review.
rating: Option<String>Star rating for this review. Possible values are ONE, TWO, THREE, FOUR, FIVE or NOT_RATED.
source: Option<ReviewSource>Information regarding the source of this review, when the review is not from a Google Books user.
title: Option<String>Title for this review.
type_: Option<String>Source type for this review. Possible values are EDITORIAL, WEB_USER or GOOGLE_USER.
volume_id: Option<String>Volume that this review is for.