pub struct ReviewSource {
pub description: Option<String>,
pub extra_description: Option<String>,
pub url: Option<String>,
}Expand description
Information regarding the source of this review, when the review is not from a Google Books user.
This type is not used in any activity, and only used as part of another schema.
Fields
description: Option<String>Name of the source.
extra_description: Option<String>Extra text about the source of the review.
url: Option<String>URL of the source of the review.