pub struct Volume2 {
pub items: Option<Vec<Volume>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list category volumes onboarding (response)
Fields
items: Option<Vec<Volume>>A list of volumes.
kind: Option<String>Resource type.
next_page_token: Option<String>no description provided