pub struct Annotationsdata {
pub items: Option<Vec<GeoAnnotationdata>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub total_items: Option<i32>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- annotation data list layers (response)
Fields
items: Option<Vec<GeoAnnotationdata>>A list of Annotation Data.
kind: Option<String>Resource type
next_page_token: Option<String>Token to pass in for pagination for the next page. This will not be present if this request does not have more results.
total_items: Option<i32>The total number of volume annotations found.