pub struct VolumeLayerInfoLayers {
pub layer_id: Option<String>,
pub volume_annotations_version: Option<String>,
}Expand description
A layer should appear here if and only if the layer exists for this book.
This type is not used in any activity, and only used as part of another schema.
Fields
layer_id: Option<String>The layer id of this layer (e.g. “geo”).
volume_annotations_version: Option<String>The current version of this layer’s volume annotations. Note that this version applies only to the data in the books.layers.volumeAnnotations.* responses. The actual annotation data is versioned separately.